// hourly wind forecasting

set more off
 

// load data and reshape to wide
use "allstations", clear

reshape wide pm co t hr vv dv station, i(datevec) j(id)
tsset datevec, delta(1 hour)

//choose station  
// 1  = cerillos
// 2  = cerronavia
// 3  = condes
// 4  = elbosque
// 5  = independencia
// 6  = la florida
// 7  = parque o'higgins
// 8  = pudahuel
// 9  = puente alto
// 10 = quilicura
// 11 = talagante


// El Bosque
local id = 4
rename vv`id' v
rename dv`id' dv

// generate month of the year
gen month =  month(dofc(datevec))        	// month of the year
gen week  =  week(dofc(datevec)) 			// week of the year
gen hour   = hh(datevec)					// hour of the day
replace hour = hour +1

gen t = _n
tsset t

/* ------------------- Linear regression with seasonals --------------------- */
reg v i.month i.hour L.v L24.v 

estimates store linreg

capt drop uhat
predict uhat, r
ac uhat, recast(bar) fcolor(none) scheme(s1mono) ytitle("Autocorrelations") ///
		xtitle("") note("") ylabel(,angle(0)) name(acf1, replace) ///
		title("Linear regression model", size(medsmall))


forecast create linreg, replace
forecast estimates linreg
forecast solve, prefix(linreg_) begin(40872)  


/* ---------------------- Seasonal ARIMA ------------------------------------ */
xi: arima v i.month, arima(1,0,1) sarima(1,0,1,24)  nolog vsquish

estimates store sarima
capture drop uhat
predict uhat, r
ac uhat, recast(bar) fcolor(none) scheme(s1mono) ytitle("Autocorrelations") ///
		xtitle("") note("") ylabel(,angle(0)) name(acf2, replace) ///
		title("Seasonal ARMA model", size(medsmall))


graph combine acf1 acf2, ycom imargin(tiny) scheme(s1mono)



forecast create sarima, replace
forecast estimates sarima, 
forecast solve, prefix(sarma_) begin(40872) 


fcstats2 v linreg_v sarma_v in 40872/l


