
clear *
set more off
set scheme s1mono


// load quarterly data
use "greensolow.dta", clear
tsset datevec, quarterly

replace gdp = log(gdp)

// generate growth rates
gen Dco2 =  log(co2)- log(L1.co2) 	
gen Dgdp =  D.gdp
gen Dp   = log(p)-log(L1.p) 	
gen Dlp  = log(lp) - log(L1.lp)	
gen Drc  = log(rc) - log(L1.rc)	  

// short run restrictions
use "vars.dta", clear
matrix A = (1,0\.,1)
matrix B = (.,0\0,.)
svar Dlp Dco2 if tin(1973q1,2012q1), aeq(A) beq(B) lags(1) var dfk small nolog vsquish

matrix Aest = e(A)
matrix Best = e(B)
matrix chol_est = inv(Aest)*Best
matrix list chol_est

matrix sig_var = e(Sigma)
matrix chol_var = cholesky(sig_var)
matrix list chol_var


use "vars.dta", clear
matrix C = (.,0,0\.,.,0\.,.,.)
matrix list C
svar Dp Dlp Dco2 if tin(1973q1,2012,q1), lreq(C) lags(1/4) nolog  

irf create co2cycle, step(8) set(co2cycles) replace
 
	
irf graph coirf, irf(co2cycle)	impulse(Dp) response(Dco2) individual ustep(20) ///
	xtitle("Forecast horizon (quarters)") legend(off) ///
	title("Investment shock", size(medsmall)) iname(g1, replace) xlab(#5) ysc(range(-0.01 0.01)) ///
	ylab(, angle(0)) aspect(1)
gr_edit .subtitle.draw_view.setstyle, style(no)

irf graph coirf, irf(co2cycle)	impulse(Dlp) response(Dco2) individual ustep(20) ///
	xtitle("Forecast horizon (quarters)") legend(off) ///
	title("Technology shock", size(medsmall)) iname(g2, replace) xlab(#5) ysc(range(-0.01 0.01)) ///
	ylab(, angle(0)) aspect(1)
gr_edit .subtitle.draw_view.setstyle, style(no)

graph combine g21 g11 ,  rows(1)  imargin(tiny)
 
 

