// logged dependent variables

clear *
set more off
 

// load data and reshape to wide
use "allstations", clear
reshape wide pm co t hr vv dv station, i(datevec) j(id)
tsset datevec, delta(1 hour)
local id = 4
rename vv`id' v
rename dv`id' dv
generate lv = log(v)
twoway hist v, frequency fcolor(none) ytitle("Frequency") ylabel(, angle(0)) ///
			xtitle("") xlabel(, format(%3.1f) ) name(h1, replace) scheme(s1mono) ///
			title("Distribution of hourly wind speed",size(medsmall))
twoway hist lv, frequency fcolor(none) ytitle("Frequency") ylabel(, angle(0)) ///
			xtitle("") xlabel(, format(%3.1f) ) name(h2, replace) scheme(s1mono) ///
			title("Distribution of log of hourly wind speed",size(medsmall))
graph combine h1 h2, imargin(tiny) scheme(s1mono)
generate dd = dofc(datevec)
format dd %td
summarize dd, mean
local ll = `r(min)'
local ul = `r(max)'
generate mdv = .
generate mdv_str = .
forvalues w=`ll'/`ul' {
	quietly circsummarize dv if dd==`w', ci
	quietly replace mdv = `r(vecmean)' if dd==`w'
	quietly replace mdv_str = `r(vecstr)' if dd==`w'
}
collapse v mdv, by(dd)
tsset dd, daily
capture drop winddir 
generate winddir = int((mdv-1)/45) + 1
label define wdlab 1 NNE 2 ENE 3 ESE 4 SSE 5 SSW 6 WSW 7 WNW 8 NNW
label value winddir wdlab
tabulate winddir, gen(wd)
rename wd1 NNE
rename wd2 ENE
rename wd3 ESE
rename wd4 SSE 
rename wd5 SSW 
rename wd6 WSW 
rename wd7 WNW 
rename wd8 NNW
generate lv = log(v)
regress lv L(1/7).lv NNE ENE ESE SSE SSW WSW WNW NNW, noconstant

scalar sig = e(rmse)
predict lfit, xb
predict uhat, resid
generate vfit = exp(lfit)
summarize v vfit if !mi(vfit)

// normal approximation
capture drop vfit
generate vfit = exp(sig^2/2)*exp(lfit)
summarize v vfit if !mi(vfit)

// regression approximation
capture drop vfit
generate vfit = exp(lfit)
regress v vfit, noco
replace vfit = _b[vfit]*vfit
summarize v vfit if !mi(vfit)

hist uhat, frequency fcolor(none) ytitle("Frequency") ylabel(, angle(0)) ///
			xtitle("") xlabel(, format(%3.1f) ) name(h3, replace) scheme(s1mono) ///
			title("Distribution of residuals",size(medsmall)) normal

// GLM with gamma likelihood and log link 	
glm v  L(1/7).v NNE ENE ESE SSE SSW WSW WNW NNW, family(gamma) link(log) nolog vsquish noconstant

capture drop vfit
predict vfit
summarize v vfit  if !mi(vfit)
