// MGARCH estimation 

clear *
set more off
set scheme s1mono

use "djsidata", replace


// keep only the data for the period in which all indices are available
tsset date
keep if tin(31jan2004,30jun2017)

// interpolate missing values for the na and eu indexes
ipolate na date, gen(tmp)
replace na=tmp
drop tmp

ipolate eu date, gen(tmp)
replace eu=tmp
drop tmp

// fix the weekend and non-trading day gaps 
generate t=_n
tsset t


// generate excess returns
generate rsp = 100*( (log(sp)-log(L.sp)) - rf )
generate rna = 100*( (log(na)-log(L.na)) - rf )
generate reu = 100*( (log(eu)-log(L.eu)) - rf )
generate rap = 100*( (log(ap)-log(L.ap)) - rf )

// estimate constant beta
quietly regress rap rsp
generate beta = _b[rsp]

// estimate required GARCH models
quietly arch rsp, arch(1) garch(1)
quietly predict hsp, var
quietly arch rap, arch(1) garch(1)
quietly predict hap, var

// constant correlation
corr rap rsp
matrix tmp = r(C)
sca rho = tmp[2,1]

// generate covariance of market and msoft based on constant correlation assumption
generate h_ap_sp = rho*sqrt(hsp)*sqrt(hap)
generate betat   = h_ap_sp/hsp

twoway line h_ap_sp date, tlabel(, format(%tdCCYY)) name(ccov, replace) ///
		xtitle("") ytitle("") ylabel(,angle(0))  title("Conditional covariance") ///
		scheme(s1mono)

twoway (line betat date) || (line beta date, lw(medthick) lc(black)), ///
		name(betat, replace) legend(off) xtitle("") ///
		xlabel(,format(%tdCCYY)) ylabel(,angle(0)) scheme(s1mono)

graph combine ccov betat, imargin(zero) scheme(s1mono) cols(1)	


// dvech model
mgarch dvech (rap rsp = ), arch(1) garch(1) vsquish nolog

predict v*, var
generate beta_ap = v_rsp_rap/v_rsp_rsp

lowess beta_ap date,  bwidth(.2) gen(bap) 


twoway (line bap date, lc(gray)) || (line beta date, lw(medthick) lc(black)), ///
		legend(off) xtitle("") xlabel(,format(%tdCCYY)) scheme(s1mono) ///
		ylabel(, angle(0))  ytitle("Asia Pacific beta") 


drop beta_ap bap

// dcc model
mgarch dcc (rna reu rap rsp = ), arch(1) garch(1) nolog vsquish

predict cvar*, var
generate beta_ap = cvar_rsp_rap/cvar_rsp_rsp
generate beta_na = cvar_rsp_rna/cvar_rsp_rsp
generate beta_eu = cvar_rsp_reu/cvar_rsp_rsp

lowess beta_ap date,  bwidth(.2) gen(bap) nodraw
lowess beta_na date,  bwidth(.2) gen(bna) nodraw
lowess beta_eu date,  bwidth(.2) gen(beu) nodraw

twoway (line bna date, lc(black)) || (line beu date, lc(gs5) lp(longdash)) || ///
		(line bap date, lc(gs10) lp(dash)), ///
		xtitle("") xlabel(,format(%tdCCYY)) ylabel(,angle(0)) ///
		scheme(s1mono) ytitle("DJSI betas") ///
		legend(order(1 "North America" 2 "Europe" 3 "Asia Pacific") rows(1)) 

