clear *


// cfb 21mar2020: still many issues with state abbrevs not agreeing with FIPS codes;
// figures have been redone so that NJ now has FDI Chem showing. See 
// https://www.nrcs.usda.gov/wps/portal/nrcs/detail/?cid=nrcs143_013696

// load Keller and Levinson data with fixed state abbrevs
use "phh_fix", clear

// description of the data
describe

// simple correlation

corr fdi_man fdi_chem fdi_man_emp fdi_chem_emp rac
bysort id: corr fdi_chem rac

gen state = STUSPS 
/*
// dependent variable
gen lfdi = log(fdi_chem)

// abatement costs
gen lrac = log(rac)

// controls
gen lpop   = log(pop)
gen len    = log(energy)
gen lprox  = log(proximity)
gen lwages = log(av_wages)
gen lun    = log(union)
gen lump   = log(unemp)
gen lmile  = log(mileage)
gen lland  = log(land)
gen ltax   = log(tax)
*/

xtset id year
// pooled regression
use "phh_fix", clear
regress lfdi lrac lwages lpop len lprox lun lump lmile, vce(cluster id)

regress lfdi lrac lwages lpop len lprox lun lump lmile i.year, vce(cluster id) 
testparm i.year

// fixed effects, no time effects
xtreg lfdi lrac lwages lpop len lprox lun lump lmile, fe 

// fixed effects
xtreg lfdi lrac lwages lpop len lprox lun lump lmile i.year, fe 
testparm i.year
estimates store FE

// fixed effects with lag LRAC; compute SS effect
xtreg lfdi L(0/1).lrac lwages lpop len lprox lun lump lmile i.year, fe  
lincom lrac + L.lrac

// random effects
xtreg lfdi lrac lwages lpop len lprox lun lump lmile i.year, re  
testparm i.year
estimates store RE

// hausman test
hausman FE RE, sigmamore


// hybrid model
xi i.year
xthybrid lfdi lrac lwages lpop len lprox lun lump lmile _Iyear_78-_Iyear_91, ///
 use(lrac lwages len lprox lun lump) clusterid(id) full test vce(cluster id)

// hybrid model with time-invariant regressor
gen state = STUSPS 
merge m:1 state using politaffil
drop if _merge!=3
drop _merge
// alwaysRep: state always voted for Rep candidate in 1976-1992 elections (23% of sample)
tab alwaysRep
save "phh_fix_aug", replace

use "phh_fix_aug", clear
xthybrid lfdi lrac lwages lpop len lprox lun lump lmile alwaysRep ///
 _Iyear_78-_Iyear_91,  use(lrac lwages len lprox lun lump) clusterid(id) full keep vce(cluster id)


rm phh_fix_aug.dta
