// Data from
// "How do Carbon Emissions Respond to Business-Cycle Shocks?"
// by Hashmat Khan Christopher R. Knittel Konstantinos Metaxoglou and Maya Papineau

clear *
set more off
set scheme s1mono


// load quarterly data
use "greensolow.dta", clear
tsset datevec, quarterly


gen ratio = 1e06*(co2/gdp)
tsline ratio if tin(1973q1,2016q1), lpattern(solid) lc(black) ///
	legend(off) ylab(,angle(0)) tlabel(, format(%tqCCYY)) ///
	ytitle("Ratio of CO{sub:2} to DGP") xtitle("") name(g1, replace) 
		

// plot co2 versus the business cycle
replace gdp = log(gdp)

tsfilter hp co2_hp = co2 , smooth(1600)
tsfilter hp gdp_hp = gdp , smooth(1600)

// scale co2 cyclical component
gen co2sc = co2_hp*100

tsline gdp_hp co2sc if tin(1973q1,2016q1), ///
	lp(solid longdash) lc(gray black)  lw(medthick medium) ///
	legend(order(1 "Real GDP" 2 "CO2")) ylab(,angle(0)) tlabel(, format(%tqCCYY)) ///
	name(g2, replace) xtitle("")

