
clear *
set more off
set scheme s1mono



// load sunspot data and set as time series
use "annualsunspots.dta", clear
tsset datevec


// plot sunspots
twoway tsline sunspots, name(sunspots, replace) ///
	ytitle("Mean annual sunspots") xtitle("")  ///
	scheme(s1mono) ylab(,angle(0))




// search for threshold in Tong and Lin spec
// use approximately interquartile range

quietly threshold sunspots, threshvar(L2.sunspots) regionvars(L(1/2).sunspots)
estimates store Model1
quietly threshold sunspots, threshvar(L3.sunspots) regionvars(L(1/2).sunspots)
estimates store Model2
quietly threshold sunspots, threshvar(L4.sunspots) regionvars(L(1/2).sunspots)
estimates store Model3
estimates table Model1 Model2 Model3, stats(ssr aic bic hqic) star(0.1 0.05 0.01)	

 
threshold sunspots, threshvar(L3.sunspots) regionvars(L(1/2).sunspots)

capture drop fit
predict double fit, xb

twoway (tsline sunspots) (tsline fit, lp(dash) lc(gray)), ///
		yline(60.7, lc(black) lw(medthick) lp(dash)) ///
		ytitle("Actual and fitted annual sunspots") xtitle("")  name(sunspots, replace) ///
		scheme(s1mono) ylab(,angle(0)) legend(order(1 "Actual" 2 "Fitted"))




// transformation in Ghaddar and Tong
// similar results

gen x = 2*(sqrt(sunspots+1)-1)
threshold x, threshvar(L3.x) regionvars(L(1/2).x)
